document.addEventListener('DOMContentLoaded', function () {

    const versionElement = document.getElementById('version');
    if (versionElement) {
        versionElement.textContent = getExtensionVersion();
    }

    loadSites();
    document.getElementById('addSite').addEventListener('click', addSite);
    document.getElementById('save').addEventListener('click', saveSites);
});


function getExtensionVersion() {
    return chrome.runtime.getManifest().version;
}

function loadSites() {
    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        const container = document.getElementById('sitesContainer');
        container.innerHTML = '';
        sites.forEach((site, index) => {
            const div = document.createElement('div');
            div.innerHTML = `
                <input type="checkbox" id="site${index}" ${site.enabled ? 'checked' : ''}>
                <label for="site${index}">${site.name} (${site.url})</label>
                <button class="remove" data-index="${index}">הסר</button>
            `;
            container.appendChild(div);
        });
        document.querySelectorAll('.remove').forEach(button => {
            button.addEventListener('click', removeSite);
        });
    });
}

function addSite() {
    const name = document.getElementById('newSiteName').value;
    const url = document.getElementById('newSiteUrl').value;
    if (name && url) {
        chrome.storage.sync.get('sites', function (data) {
            const sites = data.sites || [];
            sites.push({ name, url, enabled: true });
            chrome.storage.sync.set({ sites }, loadSites);
        });
        document.getElementById('newSiteName').value = '';
        document.getElementById('newSiteUrl').value = '';
    }
}

function removeSite(event) {
    const index = event.target.dataset.index;
    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        sites.splice(index, 1);
        chrome.storage.sync.set({ sites }, loadSites);
    });
}

function saveSites() {
    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        sites.forEach((site, index) => {
            site.enabled = document.getElementById(`site${index}`).checked;
        });
        chrome.storage.sync.set({ sites }, function () {
            alert('ההגדרות נשמרו בהצלחה!');
        });
    });
}