document.addEventListener('DOMContentLoaded', function () {
    const versionElement = document.getElementById('version');
    if (versionElement) {
        versionElement.textContent = getExtensionVersion();
    }

    const greetingElement = document.getElementById('greeting');
    if (greetingElement) {
        greetingElement.textContent = getGreeting();
    }

    const settingsButton = document.getElementById('settingsButton');
    settingsButton.addEventListener('click', function () {
        chrome.runtime.openOptionsPage();
    });

    const refreshButton = document.getElementById('refreshButton');
    refreshButton.addEventListener('click', checkNotifications);

    checkNotifications();
});



function getExtensionVersion() {
    return chrome.runtime.getManifest().version;
}

function getGreeting() {
    const now = new Date();
    const hour = now.getHours();

    if (hour >= 5 && hour < 12) {
        return 'בוקר טוב';
    } else if (hour >= 12 && hour < 17) {
        return 'צהריים טובים';
    } else if (hour >= 17 && hour < 21) {
        return 'ערב טוב';
    } else {
        return 'לילה טוב';
    }
}


function checkNotifications() {
    const notificationsDiv = document.getElementById('notifications');
    notificationsDiv.innerHTML = `
        <div class="loading">
            <div class="spinner"></div>
            <div id="loadingText" class="loading-text">אנחנו אוספים כעת את המידע בעבורך, המתן מעט...</div>
        </div>
    `;

    chrome.storage.sync.get('sites', function (data) {
        let sites = data.sites || [];
        if (sites.length === 0) {
            sites = [
                { url: 'https://tchumim.com', name: 'תחומים', enabled: true },
                { url: 'https://mitmachim.top', name: 'מתמחים', enabled: true },
                { url: 'https://f2.freeivr.co.il', name: 'פורום ימות המשיח', enabled: true },
                { url: 'https://forum-office.co.il', name: 'פורום אופיס', enabled: true },
                { url: 'https://forum.netfree.link', name: 'פורום נטפרי', enabled: true },
                { url: 'https://forum.safera.co.il', name: 'פורום סייפר', enabled: true },
                { url: 'https://rechavimzelaze.ovh', name: 'רכבים זה לזה', enabled: true }
            ];
            chrome.storage.sync.set({ sites: sites });
        }

        let notificationHtml = '';
        let disconnectedSites = [];
        let activeUsernames = [];

        const enabledSites = sites.filter(site => site.enabled);
        let checkedSites = 0;


        function updateLoadingText(text) {
            const loadingText = document.getElementById('loadingText');
            if (loadingText) {
                loadingText.textContent = text;
            }
        }

        Promise.all(enabledSites.map(site =>
            fetch(`${site.url}/api/notifications`)
                .then(response => response.json())
                .then(data => {
                    checkedSites++;
                    updateLoadingText(`כעת בודק ${checkedSites} מתוך ${enabledSites.length} - ${site.name}`);
                    console.log(`כעת בודק ${checkedSites} מתוך ${enabledSites.length} - ${site.name}`);
                    return { site, data };
                })
                .catch(error => {
                    checkedSites++;
                    updateLoadingText(`כעת בודק ${checkedSites} מתוך ${enabledSites.length} - ${site.name}`);
                    console.log(`כעת בודק ${checkedSites} מתוך ${enabledSites.length} - ${site.name}`);
                    return { site, error };
                })
        ))
            .then(results => {
                loadingText.textContent = 'הבדיקה הושלמה';

                let totalUnreadCount = 0;


                results.forEach(({ site, data, error }) => {
                    if (error || (data.status && data.status.code === "not-authorised")) {
                        disconnectedSites.push(`<a href="${site.url}/login" target="_blank">${site.name}</a>`);
                        return;
                    }

                    const unread = data.notifications.filter(n => !n.read);
                    totalUnreadCount += unread.length;

                    if (unread.length > 0) {
                        notificationHtml += `<div class="notification-source">${site.name}: <span class="notification-count">${unread.length} התראות חדשות</span></div>`;
                        unread.forEach(n => {
                            notificationHtml += `
                                <div class="notification-item">
                                    <a href="${site.url}${n.path}" target="_blank" class="notification-link">
                                        <div class="notification-content">${n.bodyShort}</div>
                                    </a>
                                    <a href="${site.url}${n.path}" class="notification-mark-read">
                                        <div class="notification-icon">
                                            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
                                                <path stroke-linecap="round" stroke-linejoin="round" d="M9 12.75 11.25 15 15 9.75M21 12a9 9 0 1 1-18 0 9 9 0 0 1 18 0Z" />
                                            </svg>
                                        </div>
                                    </a>
                                </div>
                        `;
                        });
                    }

                    if (data.loggedInUser && data.loggedInUser.username) {
                        activeUsernames.push(`${site.name}: ${data.loggedInUser.username}`);
                    }
                });

                const notificationsDiv = document.getElementById('notifications');

                console.log('disconnectedSites: ' + disconnectedSites.length);

                if (totalUnreadCount > 0) {
                    notificationsDiv.innerHTML = notificationHtml;
                } else {
                    notificationsDiv.innerHTML = '<div class="no-notifications">אין התראות חדשות</div>';
                }

                // Add disconnected sites at the top
                if (disconnectedSites.length > 0) {

                    const disconnectedHtml = `
                    <div class="disconnected-sites">
                        <p>האתרים הבאים מנותקים:</p>
                        <ul>${disconnectedSites.map(site => `<li>${site}</li>`).join('')}</ul>
                    </div>
                `;
                    notificationsDiv.insertAdjacentHTML('afterbegin', disconnectedHtml);
                }

                // Add active usernames at the bottom
                if (activeUsernames.length > 0) {
                    notificationsDiv.innerHTML += `
                <div class="active-usernames">
                    <p>סשנים פעילים:</p>
                    <ul>${activeUsernames.map(username => `<li>${username}</li>`).join('')}</ul>
                </div>
            `;
                }
            })
            .catch(error => {
                console.error('Error:', error);
                document.getElementById('notifications').innerHTML = '<div class="no-notifications">אירעה שגיאה בבדיקת ההתראות</div>';
            });
    });
}


document.addEventListener('DOMContentLoaded', () => {
    const links = document.querySelectorAll('.notification-mark-read');

    links.forEach(link => {
        link.addEventListener('click', event => {
            event.preventDefault();
            const url = link.href;
            const iconContainer = link.querySelector('.notification-icon');

            fetch(url, {
                method: 'GET',
            })
                .then(response => {
                    if (response.ok) {
                        iconContainer.classList.add('read');
                        iconContainer.classList.remove('notification-icon');
                        iconContainer.classList.add('notification-icon-read');

                        console.log('הנושא סומן כנקרא בהצלחה');
                    } else {
                        console.error('שגיאה בסימון כנקרא');
                    }
                })
                .catch(error => {
                    console.error('שגיאת רשת:', error);
                });
        });
    });
});

